@@ -2,15 +2,15 @@ import logging
 from datetime import datetime
 from traceback import format_exc
 import pytz
-from fipper import ContinuePropagation, StopPropagation, filters
-from fipper.enums import ChatMemberStatus, ChatType
-from fipper.errors.exceptions.bad_request_400 import (
+from pyroge import ContinuePropagation, StopPropagation, filters
+from pyroge.enums import ChatMemberStatus, ChatType
+from pyroge.errors.exceptions.bad_request_400 import (
     MessageIdInvalid,
     MessageNotModified,
     MessageEmpty,
     UserNotParticipant
 )
-from fipper.handlers import MessageHandler
+from pyroge.handlers import MessageHandler
 
 from pygeez.pyrogram import eor
 
